---
linkTitle: Advanced
title: Advanced Topics
prev: /docs/guide/shortcodes/tabs
next: /docs/advanced/multi-language
---

This section covers some advanced topics of the theme.

<!--more-->

{{< cards >}}
  {{< card link="multi-language" title="Multi-language" icon="translate" >}}
  {{< card link="customization" title="Customization" icon="pencil" >}}
  {{< card link="comments" title="Comments System" icon="chat-alt" >}}
{{< /cards >}}
